==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebCellTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCellTypeDescriptionMetadata } from "./WebCellTypeDescriptionMetadata";
import { WebCellTemplateContextDescription } from "./WebCellTemplateContextDescription";
/**
 * @hidden
 */
export let WebCellTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCellTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebCellTemplateContextDescriptionMetadata.a == null) {
                WebCellTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCellTemplateContextDescriptionMetadata.c(WebCellTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebCellTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebCellTemplateContextDescriptionMetadata.a);
            WebCellTypeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CellTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Implicit", "Unknown");
            a.item("AdditionalTemplateContext", "Unknown");
            a.item("Cell", "ExportedType:WebCellType");
        }
        static d(a) {
            WebCellTemplateContextDescriptionMetadata.b(a);
            a.aa("WebCellTemplateContext", () => new WebCellTemplateContextDescription());
            a.z("WebCellTemplateContext", WebCellTemplateContextDescriptionMetadata.a);
        }
    }
    WebCellTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCellTemplateContextDescriptionMetadata, 'WebCellTemplateContextDescriptionMetadata');
    WebCellTemplateContextDescriptionMetadata.a = null;
    return WebCellTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebCellTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCellTypeDescriptionMetadata } from "./WebCellTypeDescriptionMetadata";
import { WebCellTemplateContextDescription } from "./WebCellTemplateContextDescription";
/**
 * @hidden
 */
export let WebCellTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCellTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebCellTemplateContextDescriptionMetadata.a == null) {
                WebCellTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCellTemplateContextDescriptionMetadata.c(WebCellTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebCellTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCellTemplateContextDescriptionMetadata.a);
            WebCellTypeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CellTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "Unknown");
            a.item("AdditionalTemplateContext", "Unknown");
            a.item("Cell", "ExportedType:WebCellType");
        }
        static d(a) {
            WebCellTemplateContextDescriptionMetadata.b(a);
            a.ac("WebCellTemplateContext", () => new WebCellTemplateContextDescription());
            a.ab("WebCellTemplateContext", WebCellTemplateContextDescriptionMetadata.a);
        }
    }
    WebCellTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCellTemplateContextDescriptionMetadata, 'WebCellTemplateContextDescriptionMetadata');
    WebCellTemplateContextDescriptionMetadata.a = null;
    return WebCellTemplateContextDescriptionMetadata;
})();
